package com.gxzc.zen.api.sys.service.impl

import com.baomidou.mybatisplus.mapper.EntityWrapper
import com.baomidou.mybatisplus.plugins.Page
import com.baomidou.mybatisplus.service.impl.ServiceImpl
import com.gxzc.zen.api.sys.mapper.SysRoleMapper
import com.gxzc.zen.api.sys.model.SysRole
import com.gxzc.zen.api.sys.service.ISysRoleService
import com.gxzc.zen.common.exception.ZenException
import com.gxzc.zen.common.exception.ZenExceptionEnum
import org.springframework.stereotype.Service
import java.io.Serializable

/**
 * <p>
 * 角色表 服务实现类
 * </p>
 *
 * @author NorthLan123
 * @since 2018-02-06
 */
@Service
class SysRoleServiceImpl : ServiceImpl<SysRoleMapper, SysRole>(), ISysRoleService {
    override fun getRoleListByUserId(userId: Long?): MutableList<SysRole> {
        if (userId == null) {
            return mutableListOf()
        }
        return baseMapper.selectByUserId(userId)
    }

    override fun getRoleListPage(keyword: String?, searchOption: Int?, page: Page<SysRole>, enable: Boolean?): Page<SysRole> {
        val condition = EntityWrapper<SysRole>().apply {
            if (!keyword.isNullOrEmpty() && searchOption != null) {
                when (searchOption) {
                    1 -> {
                        // 角色名称
                        like("name", "%$keyword%")
                    }
                    2 -> {
                        // 角色代码
                        like("code", "%$keyword%")
                    }
                }
            }
            if (enable != null) {
                if (enable) {
                    eq("enable", 1)
                } else {
                    eq("enable", 0)
                }
            }
        }
        page.records = baseMapper.selectWOLogicPage(page, condition)
        return page
    }

    override fun getRoleList(keyword: String?, searchOption: Int?, enable: Boolean?): MutableList<SysRole> {
        val condition = EntityWrapper<SysRole>().apply {
            if (!keyword.isNullOrEmpty() && searchOption != null) {
                when (searchOption) {
                    1 -> {
                        // 角色名称
                        like("name", "%$keyword%")
                    }
                    2 -> {
                        // 角色代码
                        like("code", "%$keyword%")
                    }
                }
            }
            if (enable != null) {
                if (enable) {
                    eq("enable", 1)
                } else {
                    eq("enable", 0)
                }
            }
        }
        return baseMapper.selectWOLogic(condition)
    }

    override fun physicalDeleteById(id: Serializable) {
        if (baseMapper.physicalDeleteById(id) <= 0) {
            throw ZenException(ZenExceptionEnum.BIZ_DELETE_ERROR)
        }
    }

    override fun updateLogicById(entity: SysRole) {
        if (baseMapper.updateWOLogic(entity, EntityWrapper<SysRole>().eq("id", entity.id)) <= 0) {
            throw ZenException(ZenExceptionEnum.BIZ_UPDATE_ERROR)
        }
    }
}
