package com.gxzc.zen.web.sys.controller

import com.gxzc.zen.api.sys.model.SysDictType
import com.gxzc.zen.api.sys.model.SysDictValue
import com.gxzc.zen.api.sys.service.ISysDictTypeService
import com.gxzc.zen.api.sys.service.ISysDictValueService
import com.gxzc.zen.common.base.BaseController
import com.gxzc.zen.common.dto.ResponseDto
import io.swagger.annotations.ApiOperation
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.http.ResponseEntity
import org.springframework.web.bind.annotation.*

/**
 * 字典 控制器
 * @author NorthLan
 * @date 2018/5/5
 * @url https://noahlan.com
 */
@RestController
@RequestMapping("dict")
class DictController : BaseController() {
    @Autowired
    private lateinit var dictTypeService: ISysDictTypeService
    @Autowired
    private lateinit var dictValueService: ISysDictValueService

    @ApiOperation("获取字典树")
    @GetMapping("type/tree")
    fun getDictTypeTree(): ResponseEntity<*> {
        return ResponseEntity.ok(ResponseDto().apply {
            this.data = dictTypeService.getDictTypeTree()
        })
    }

    @ApiOperation("新增字典类别")
    @PostMapping("type")
    fun addDictType(@RequestBody entity: SysDictType): ResponseEntity<*> {
        return ResponseEntity.ok(ResponseDto().apply {
            this.data = dictTypeService.createDictType(entity)
        })
    }

    @ApiOperation("删除字典类别树及其所有子孙")
    @DeleteMapping("type/{id}")
    fun deleteDictType(@PathVariable id: Long?): ResponseEntity<*> {
        dictTypeService.deleteDictType(id)
        return ResponseEntity.ok(ResponseDto())
    }

    @ApiOperation("更新字典类别树节点信息,不包含移动树节点")
    @PutMapping("type/{id}")
    fun updateDictType(@PathVariable id: Long, @RequestBody entity: SysDictType): ResponseEntity<*> {
        return ResponseEntity.ok(ResponseDto().apply {
            this.data = dictTypeService.updateDictType(entity)
        })
    }

    @ApiOperation("获取字典值列表,若传参typeId 则取某typeid下的所有字典值")
    @GetMapping("value/list")
    fun getDictValueByTypeId(@RequestParam("typeId", required = false) typeId: Long?): ResponseEntity<*> {
        val result = if (typeId == null) {
            dictValueService.getListCacheable()
        } else {
            dictValueService.getListByTypeId(typeId)
        }
        return ResponseEntity.ok(ResponseDto().apply {
            this.data = result
        })
    }

    @ApiOperation("在某节点下插入字典值")
    @PostMapping("value")
    fun addDictValue(@RequestBody entity: SysDictValue): ResponseEntity<*> {
        return ResponseEntity.ok(ResponseDto().apply {
            this.data = dictValueService.insertDictValue(entity)
        })
    }

    @ApiOperation("删除字典值")
    @DeleteMapping("value/{id}")
    fun deleteDictValueById(@PathVariable id: Long): ResponseEntity<*> {
        dictValueService.deleteDictValue(id)
        return ResponseEntity.ok(ResponseDto())
    }

    @ApiOperation("更新字典值")
    @PutMapping("value/{id}")
    fun updateDictValue(@PathVariable id: Long, @RequestBody entity: SysDictValue): ResponseEntity<*> {
        return ResponseEntity.ok(ResponseDto().apply {
            this.data = dictValueService.updateDictValue(entity)
        })
    }

    @ApiOperation("根据type_code(code前缀)获取字典值列表")
    @GetMapping("value/typeCode")
    fun getDictValueListByTypeCode(@RequestParam("typeCode") typeCode: String): ResponseEntity<*> {
        return ResponseEntity.ok(ResponseDto().apply {
            this.data = dictValueService.getDictValueListByTypeCode(typeCode)
        })
    }

    @ApiOperation("根据code值与value获取指定字典值")
    @GetMapping("value/codeValue")
    fun getDictValueByCodeAndValue(@RequestParam("code") code: String, @RequestParam("value") value: String): ResponseEntity<*> {
        return ResponseEntity.ok(ResponseDto().apply {
            this.data = dictValueService.getDictValueByCodeAndValue(code, value)
        })
    }
}